@@ -55,7 +55,7 @@
 //       and reduce Exiv2 dependency to client code.
 
 // The pragmas are required to be able to catch exceptions thrown by libexiv2:
-// See http://gcc.gnu.org/wiki/Visibility, the section about c++ exceptions.
+// See https://gcc.gnu.org/wiki/Visibility, the section about c++ exceptions.
 // They are needed for all libexiv2 versions that do not care about visibility.
 #ifdef __GNUC__
 #pragma GCC visibility push(default)
@@ -70,8 +70,8 @@
 #endif
 
 // With exiv2 > 0.20.0, all makernote header files have been removed to increase binary compatibility.
-// See Exiv2 bugzilla entry http://dev.exiv2.org/issues/719
-// and wiki topic           http://dev.exiv2.org/boards/3/topics/583
+// See Exiv2 bugzilla entry https://dev.exiv2.org/issues/719
+// and wiki topic           https://dev.exiv2.org/boards/3/topics/583
 
 #ifdef __GNUC__
 #pragma GCC visibility pop
@@ -222,9 +222,9 @@ public:
      * Only keys in keys are considered for merging.
      * Fields from src take precedence over existing data from dest.
      */
-    void mergeFields(const Data& src, Data& dest)
+    void mergeFields(const Data& src, Data& dest) const
     {
-        foreach (const KeyString& keyString, keys)
+        for (const KeyString& keyString : keys)
         {
             Key key(keyString.latin1());
             typename Data::const_iterator it = src.findKey(key);
@@ -254,9 +254,9 @@ public:
      * Keys must exist in src to kept in dest.
      * Fields from src take precedence over existing data from dest.
      */
-    void exclusiveMerge(const Data& src, Data& dest)
+    void exclusiveMerge(const Data& src, Data& dest) const
     {
-        foreach (const KeyString& keyString, keys)
+        for (const KeyString& keyString : keys)
         {
             Key key(keyString.latin1());
             typename Data::const_iterator it = src.findKey(key);
